<?php

namespace Litecms\Buses\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Buses\Models\Buses;

class BusesPolicy
{

    /**
     * Determine if the given user can view the buses.
     *
     * @param UserPolicy $user
     * @param Buses $buses
     *
     * @return bool
     */
    public function view(UserPolicy $user, Buses $buses)
    {
        if ($user->canDo('buses.buses.view') && $user->isAdmin()) {
            return true;
        }

        return $buses->user_id == user_id() && $buses->user_type == user_type();
    }

    /**
     * Determine if the given user can create a buses.
     *
     * @param UserPolicy $user
     * @param Buses $buses
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('buses.buses.create');
    }

    /**
     * Determine if the given user can update the given buses.
     *
     * @param UserPolicy $user
     * @param Buses $buses
     *
     * @return bool
     */
    public function update(UserPolicy $user, Buses $buses)
    {
        if ($user->canDo('buses.buses.edit') && $user->isAdmin()) {
            return true;
        }

        return $buses->user_id == user_id() && $buses->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given buses.
     *
     * @param UserPolicy $user
     * @param Buses $buses
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Buses $buses)
    {
        return $buses->user_id == user_id() && $buses->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given buses.
     *
     * @param UserPolicy $user
     * @param Buses $buses
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Buses $buses)
    {
        if ($user->canDo('buses.buses.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given buses.
     *
     * @param UserPolicy $user
     * @param Buses $buses
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Buses $buses)
    {
        if ($user->canDo('buses.buses.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
